Octocat
#######

.. _description:

Octocat -- Python client for Github API.

.. _badges:

.. image:: https://secure.travis-ci.org/klen/octocat.png?branch=develop
    :target: http://travis-ci.org/klen/octocat
    :alt: Build Status

.. image:: https://pypip.in/d/octocat/badge.png
    :target: https://pypi.python.org/pypi/octocat

.. image:: https://badge.fury.io/py/octocat.png
    :target: http://badge.fury.io/py/octocat

.. _documentation:

**Docs are available at https://octocat.readthedocs.org/. Pull requests
with documentation enhancements and/or fixes are awesome and most welcome.**

.. _contents:

.. contents::

.. _requirements:

Requirements
=============

- python >= 2.6

.. _installation:

Installation
=============

**Octocat** should be installed using pip: ::

    pip install octocat

.. _usage:

Usage
=====

.. _bugtracker:

Bug tracker
===========

If you have any suggestions, bug reports or
annoyances please report them to the issue tracker
at https://github.com/klen/octocat/issues

.. _contributing:

Contributing
============

Development of Octocat happens at github: https://github.com/klen/octocat


Contributors
=============

* klen_ (Kirill Klenov)

.. _license:

License
=======

Licensed under a `BSD license`_.

.. _links:

.. _BSD license: http://www.linfo.org/bsdlicense.html
.. _klen: http://klen.github.com/
